@@ -48,7 +48,7 @@ void Sharing::setBusy(bool isBusy, const QString &message, int numberOfOperation
             emit busy(message, numberOfOperations);
         }
         else {
-            emit busyProgressChanged(1);
+            emit busyProgressChanged(numberOfOperations);
         }
 
         emit busyChanged(isBusy);
