@@ -48,7 +48,7 @@ void Vimeo::setBusy(bool isBusy, const QString &message, int numberOfOperations)
             emit busy(message, numberOfOperations);
         }
         else {
-            emit busyProgressChanged(1);
+            emit busyProgressChanged(numberOfOperations);
         }
 
         emit busyChanged(isBusy);
