@@ -55,7 +55,7 @@ void YouTube::setBusy(bool isBusy, const QString &message, int numberOfOperation
             emit busy(message, numberOfOperations);
         }
         else {
-            emit busyProgressChanged(1);
+            emit busyProgressChanged(numberOfOperations);
         }
 
         emit busyChanged(isBusy);
