@@ -1,14 +1,15 @@
 #ifndef EVENTS_H
 #define EVENTS_H
 
-#include "youtube.h"
-#include "dailymotion.h"
-#include "database.h"
 #include "event.h"
-#include <QNetworkAccessManager>
-#include <QStringList>
 #include <QDateTime>
 
+class YouTube;
+class Dailymotion;
+class Vimeo;
+class Database;
+class QNetworkAccessManager;
+
 class Events : public QObject
 {
     Q_OBJECT
@@ -18,8 +19,8 @@ public:
     ~Events() {}
 
 public slots:
-    void enableSync();
-    void disableSync();
+    bool enableSync();
+    bool disableSync();
     void startSync();
 
 private slots:
@@ -31,20 +32,28 @@ private slots:
     void processYouTubeEvents();
     void getDailymotionEvents();
     void processDailymotionEvents();
+    void getVimeoEvents();
+    void processVimeoEvents();
+    void onThumbnailDownloaded();
 
 private:
     void init();
     void addEvents();
+    QString base64SerializedVariant(const QVariant &value) const;
+    void downloadThumbnails();
 
 private:
     QNetworkAccessManager *m_nam;
     Database *m_database;
     YouTube *m_youtube;
     Dailymotion *m_dailymotion;
+    Vimeo *m_vimeo;
     QList<Event> m_events;
+    int m_index;
     bool m_initialized;
-    QDateTime m_lastRun;
-    QDateTime m_thisRun;
+    QDateTime m_youtubeLatest;
+    QDateTime m_dailymotionLatest;
+    QDateTime m_vimeoLatest;
 };
 
 #endif  //  EVENTS_H
